package project35.lymeDisease;

import project35.soa.validation.RecordModelValidationService;
import project35.soa.alerts.SystemErrorAlert;
import project35.system.Project35FormContext;
import project35.system.Project35Resources;
import project35.mda.model.*;
import project35.util.Parameter;

import java.util.ArrayList;
import java.text.Collator;
import java.net.URL;

/**
 * if the erythma_migrans is a factor in the assessment of the 
 * dermatological system, the user must specify an onset date
 * <hr>
 * Copyright (c) 2008 Kevin Garwood for Project35.  This code is 
 * licensed under the Academic Free License version 3.0.  For more information 
 * on the terms and conditions, please see the file "LICENSE" that is included 
 * in this distribution.
 * <hr>
 *
 * @author Kevin Garwood (kgarwood@users.sourceforge.net)
 * @version 1.0	
 */

/*
 * Code Road Map:
 * --------------
 * Code is organised into the following sections.  Wherever possible, 
 * methods are classified based on an order of precedence described in 
 * parentheses (..).  For example, if you're trying to find a method 
 * 'getName(...)' that is both an interface method and an accessor 
 * method, the order tells you it should appear under interface.
 * 
 * Order of 
 * Precedence     Section
 * ==========     ======
 * (1)            Section Constants
 * (2)            Section Properties
 * (3)            Section Construction
 * (8)            Section Accessors
 * (9)            Section Mutators
 * (6)            Section Validation
 * (7)            Section Errors
 * (5)            Section Interfaces
 * (4)            Section Overload
 *
*/

public class ErythemaMigransRecordValidationService implements
RecordModelValidationService {

   // ==========================================
   // Section Constants
   // ==========================================
 
   // ==========================================
   // Section Properties
   // ==========================================

   // ==========================================
   // Section Construction
   // ==========================================

   // ==========================================
   // Section Accessors
   // ==========================================

   // ==========================================
   // Section Mutators
   // ==========================================

   // ==========================================
   // Section Validation
   // ==========================================

   // ==========================================
   // Section Errors
   // ==========================================

   // ==========================================
   // Section Interfaces
   // ==========================================
   
   //Interface: project35.soa.validation.RecordModelValidationService, 
   //which is a sub-interface of project35.soa.ServiceClass
   public ArrayList validate(Project35FormContext project35FormContext, 
							 RecordModel dermatologicSystemRecordModel) throws Exception {

	  ArrayList errors = new ArrayList();

	  String hasErythemaMigrans
		 = dermatologicSystemRecordModel.getValue("erythema_migrans");
	  //
	  Collator collator = Project35Resources.getCollator();
	  if ( collator.equals("yes",
						   hasErythemaMigrans) == true) {
		 String onsetDate
			= dermatologicSystemRecordModel.getValue("onset_date");
		 if ( collator.equals(onsetDate,
							  Project35Resources.EMPTY_STRING) == true) {
			//ERROR:
			StringBuffer errorMessage = new StringBuffer();
			errorMessage.append("Please specify an onset date");
			SystemErrorAlert systemErrorAlert
			   = new SystemErrorAlert(errorMessage.toString() );
			errors.add(systemErrorAlert);
		 } //end if ()
		 
	  } //end if ()
	  
	  return errors;
   }

   //Interface: ServiceClass
   public Parameter[] getInitialisationParameters() {
	  //not used
	  return(new Parameter[0]);
   }

   public void initialiseService(URL resourceDirectory,
								 Parameter[] initialisationParameters) throws Exception {
	  //not used
   }

   // ==========================================
   // Section Overload
   // ==========================================

}
